@@ -27,6 +27,7 @@ from libcloud.common.base import Response
 
 from rackspace_monitoring.providers import Provider
 from rackspace_monitoring.utils import to_underscore_separated
+from rackspace_monitoring.utils import value_to_bool
 
 from rackspace_monitoring.base import (MonitoringDriver, Entity,
                                       NotificationPlan, MonitoringZone,
@@ -251,7 +252,7 @@ class RackspaceMonitoringDriver(MonitoringDriver):
             chunk = chunks[i]
 
             if not chunk:
-              continue
+                continue
 
             key = self._plural_to_singular(chunk) + '_id'
             key = to_underscore_separated(key)
@@ -327,7 +328,8 @@ class RackspaceMonitoringDriver(MonitoringDriver):
         if 'why' in kwargs and kwargs['why'] is not None:
             params['_why'] = kwargs['why']
 
-        resp = self.connection.request(action=url, method='DELETE', params=params)
+        resp = self.connection.request(action=url, method='DELETE',
+                                       params=params)
         return resp.status == httplib.NO_CONTENT
 
     def list_check_types(self):
@@ -394,10 +396,12 @@ class RackspaceMonitoringDriver(MonitoringDriver):
 
     def _to_alarm_changelog(self, values, value_dict):
         alarm_changelog = AlarmChangelog(id=values['id'],
-                                         alarm_id=values['alarm_id'],
-                                         entity_id=values['entity_id'],
-                                         check_id=values['check_id'],
-                                         state=values['state'])
+                                       alarm_id=values['alarm_id'],
+                                       entity_id=values['entity_id'],
+                                       check_id=values['check_id'],
+                                       previous_state=values['previous_state'],
+                                       timestamp=values['timestamp'],
+                                       state=values['state'])
         return alarm_changelog
 
     def delete_alarm(self, alarm, **kwargs):
@@ -533,6 +537,7 @@ class RackspaceMonitoringDriver(MonitoringDriver):
             'target_resolver': obj.get('target_resolver', None),
             'type': obj['type'],
             'details': obj.get('details', {}),
+            'disabled': value_to_bool(obj.get('disabled', '0')),
             'driver': self,
             'entity_id': value_dict['entity_id']})
 
@@ -550,10 +555,11 @@ class RackspaceMonitoringDriver(MonitoringDriver):
                 'label': kwargs.get('label'),
                 'timeout': kwargs.get('timeout', 29),
                 'period': kwargs.get('period', 30),
-                "monitoring_zones_poll": kwargs.get('monitoring_zones', []),
-                "target_alias": kwargs.get('target_alias'),
-                "target_resolver": kwargs.get('target_resolver'),
+                'monitoring_zones_poll': kwargs.get('monitoring_zones', None),
+                'target_alias': kwargs.get('target_alias'),
+                'target_resolver': kwargs.get('target_resolver'),
                 'type': kwargs.get('type'),
+                'disabled': kwargs.get('disabled', None),
                 'details': kwargs.get('details'),
                 }
 
@@ -576,6 +582,7 @@ class RackspaceMonitoringDriver(MonitoringDriver):
             data=data, coerce=self.get_check)
 
     def update_check(self, check, data, **kwargs):
+        data = self._check_kwarg_to_data(kwargs=data)
         return self._update("/entities/%s/checks/%s" % (check.entity_id,
                                                         check.id),
             data=data, kwargs=kwargs, coerce=self.get_check)
